==> org.eclipse.linuxtools.tmf.ui.source_0.5.0.201205291936.jar: org/eclipse/linuxtools/internal/tmf/ui/Messages.java <==
package org.eclipse.linuxtools.internal.tmf.ui;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
    private static final String BUNDLE_NAME = "org.eclipse.linuxtools.internal.tmf.ui.messages"; //$NON-NLS-1$

    public static String ManageCustomParsersDialog_DeleteButtonLabel;
    public static String ManageCustomParsersDialog_DeleteConfirmation;
    public static String ManageCustomParsersDialog_DeleteParserDialogHeader;
    public static String ManageCustomParsersDialog_DialogHeader;
    public static String ManageCustomParsersDialog_EditButtonLabel;
    public static String ManageCustomParsersDialog_ExportButtonLabel;
    public static String ManageCustomParsersDialog_ExportParserSelection;
    public static String ManageCustomParsersDialog_ImportButtonLabel;
    public static String ManageCustomParsersDialog_ImportParserSelection;
    public static String ManageCustomParsersDialog_NewButtonLabel;
    public static String ManageCustomParsersDialog_ParseButtonLabel;
    public static String ManageCustomParsersDialog_ParseError;
    public static String ManageCustomParsersDialog_TextButtonLabel;
    public static String ManageCustomParsersDialog_TraceSelection;

    public static String CustomTraceDefinition_messageTag;
    public static String CustomTraceDefinition_otherTag;
    public static String CustomTraceDefinition_timestampTag;
    public static String CustomTxtTraceDefinition_action;
    public static String CustomTxtTraceDefinition_cardinality;
    public static String CustomTxtTraceDefinition_definition;
    public static String CustomTxtTraceDefinition_definitionRootElement;
    public static String CustomTxtTraceDefinition_format;
    public static String CustomTxtTraceDefinition_inputData;
    public static String CustomTxtTraceDefinition_inputLine;
    public static String CustomTxtTraceDefinition_max;
    public static String CustomTxtTraceDefinition_min;
    public static String CustomTxtTraceDefinition_name;
    public static String CustomTxtTraceDefinition_outputColumn;
    public static String CustomTxtTraceDefinition_regEx;
    public static String CustomTxtTraceDefinition_timestampOutputFormat;
    public static String CustomXmlTraceDefinition_action;
    public static String CustomXmlTraceDefinition_attribute;
    public static String CustomXmlTraceDefinition_definition;
    public static String CustomXmlTraceDefinition_definitionRootElement;
    public static String CustomXmlTraceDefinition_format;
    public static String CustomXmlTraceDefinition_ignoreTag;
    public static String CustomXmlTraceDefinition_inputData;
    public static String CustomXmlTraceDefinition_inputElement;
    public static String CustomXmlTraceDefinition_logEntry;
    public static String CustomXmlTraceDefinition_name;
    public static String CustomXmlTraceDefinition_outputColumn;
    public static String CustomXmlTraceDefinition_timestampOutputFormat;

    public static String TmfEventsTable_AddBookmarkActionText;
    public static String TmfEventsTable_AddBookmarkDialogText;
    public static String TmfEventsTable_AddBookmarkDialogTitle;
    public static String TmfEventsTable_ApplyPresetFilterMenuName;
    public static String TmfEventsTable_ClearFiltersActionText;
    public static String TmfEventsTable_ContentColumnHeader;
    public static String TmfEventsTable_FilterHint;
    public static String TmfEventsTable_HideRawActionText;
    public static String TmfEventsTable_HideTableActionText;
    public static String TmfEventsTable_ReferenceColumnHeader;
    public static String TmfEventsTable_RemoveBookmarkActionText;
    public static String TmfEventsTable_SearchHint;
    public static String TmfEventsTable_SearchingJobName;
    public static String TmfEventsTable_ShowFilterBarActionText;
    public static String TmfEventsTable_ShowRawActionText;
    public static String TmfEventsTable_ShowSearchBarActionText;
    public static String TmfEventsTable_ShowTableActionText;
    public static String TmfEventsTable_SourceColumnHeader;
    public static String TmfEventsTable_TimestampColumnHeader;
    public static String TmfEventsTable_TypeColumnHeader;

    public static String TmfTimeFilterDialog_EDIT_PROFILING_OPTIONS;
    public static String TmfTimeFilterDialog_TRACE_FILTER;
    public static String TmfTimeFilterDialog_TRACE_FILTER_DESC;
    public static String TmfTimeFilterDialog_TRACE_ID;
    public static String TmfTimeFilterDialog_TRACE_NAME;
    public static String TmfTimeLegend_LEGEND;
    public static String TmfTimeLegend_TRACE_STATES;
    public static String TmfTimeLegend_TRACE_STATES_TITLE;
    public static String TmfTimeLegend_WINDOW_TITLE;
    public static String TmfTimeLegend_StateTypeName;

    public static String TmfTimeStatesCtrl_TRACE_GROUP_LABEL;
    public static String TmfTimeStatesCtrl_UNDEFINED_GROUP;
    public static String TmfTimeTipHandler_DURATION;
    public static String TmfTimeTipHandler_NUMBER_OF_TRACES;
    public static String TmfTimeTipHandler_TRACE_DATE;
    public static String TmfTimeTipHandler_TRACE_EVENT_TIME;
    public static String TmfTimeTipHandler_TRACE_GROUP_NAME;
    public static String TmfTimeTipHandler_TRACE_NAME;
    public static String TmfTimeTipHandler_TRACE_START_TIME;
    public static String TmfTimeTipHandler_TRACE_STATE;
    public static String TmfTimeTipHandler_TRACE_STOP_TIME;

    public static String TmfTimeGraphViewer_ResetScaleActionNameText;
    public static String TmfTimeGraphViewer_ResetScaleActionToolTipText;
    public static String TmfTimeGraphViewer_LegendActionNameText;
    public static String TmfTimeGraphViewer_LegendActionToolTipText;
    public static String TmfTimeGraphViewer_NextEventActionNameText;
    public static String TmfTimeGraphViewer_NextEventActionToolTipText;
    public static String TmfTimeGraphViewer_PreviousEventActionNameText;
    public static String TmfTimeGraphViewer_PreviousEventActionToolTipText;
    public static String TmfTimeGraphViewer_NextItemActionNameText;
    public static String TmfTimeGraphViewer_NextItemActionToolTipText;
    public static String TmfTimeGraphViewer_PreviousItemActionNameText;
    public static String TmfTimeGraphViewer_PreviousItemActionToolTipText;
    public static String TmfTimeGraphViewer_ZoomInActionNameText;
    public static String TmfTimeGraphViewer_ZoomInActionToolTipText;
    public static String TmfTimeGraphViewer_ZoomOutActionNameText;
    public static String TmfTimeGraphViewer_ZoomOutActionToolTipText;
    
    public static String ColorsView_AddActionToolTipText;
    public static String ColorsView_BackgroundButtonText;
    public static String ColorsView_BackgroundDialogText;
    public static String ColorsView_DeleteActionToolTipText;
    public static String ColorsView_ExportActionToolTipText;
    public static String ColorsView_FilterButtonText;
    public static String ColorsView_ForegroundButtonText;
    public static String ColorsView_ForegroundDialogText;
    public static String ColorsView_ImportActionToolTipText;
    public static String ColorsView_ImportOverwriteDialogMessage1;
    public static String ColorsView_ImportOverwriteDialogMessage2;
    public static String ColorsView_ImportOverwriteDialogTitle;
    public static String ColorsView_MoveDownActionToolTipText;
    public static String ColorsView_MoveUpActionToolTipText;
    public static String ColorsView_TickButtonText;
    public static String TickColorDialog_TickColorDialogTitle;

    public static String CustomTxtParserInputWizardPage_addChildLine;
    public static String CustomTxtParserInputWizardPage_addGroup;
    public static String CustomTxtParserInputWizardPage_addNextLine;
    public static String CustomTxtParserInputWizardPage_append;
    public static String CustomTxtParserInputWizardPage_appendWith;
    public static String CustomTxtParserInputWizardPage_capturedGroup;
    public static String CustomTxtParserInputWizardPage_cardinality;
    public static String CustomTxtParserInputWizardPage_dateFormatHelp;
    public static String CustomTxtParserInputWizardPage_desccriptionEdit;
    public static String CustomTxtParserInputWizardPage_descriptionNew;
    public static String CustomTxtParserInputWizardPage_format;
    public static String CustomTxtParserInputWizardPage_group;
    public static String CustomTxtParserInputWizardPage_highlightAll;
    public static String CustomTxtParserInputWizardPage_logType;
    public static String CustomTxtParserInputWizardPage_matchingLineRoot;
    public static String CustomTxtParserInputWizardPage_matchingOtherLine;
    public static String CustomTxtParserInputWizardPage_matchingRootLine;
    public static String CustomTxtParserInputWizardPage_max;
    public static String CustomTxtParserInputWizardPage_min;
    public static String CustomTxtParserInputWizardPage_moveDown;
    public static String CustomTxtParserInputWizardPage_moveUp;
    public static String CustomTxtParserInputWizardPage_name;
    public static String CustomTxtParserInputWizardPage_newGroup;
    public static String CustomTxtParserInputWizardPage_noMatch;
    public static String CustomTxtParserInputWizardPage_noMatchingGroup;
    public static String CustomTxtParserInputWizardPage_noMatchingLine;
    public static String CustomTxtParserInputWizardPage_noMatchingTimestamp;
    public static String CustomTxtParserInputWizardPage_noMathcingLine;
    public static String CustomTxtParserInputWizardPage_nonMatchingLine;
    public static String CustomTxtParserInputWizardPage_noTimestampGroup;
    public static String CustomTxtParserInputWizardPage_preview;
    public static String CustomTxtParserInputWizardPage_previewInput;
    public static String CustomTxtParserInputWizardPage_previewLegend;
    public static String CustomTxtParserInputWizardPage_regularExpression;
    public static String CustomTxtParserInputWizardPage_regularExpressionHelp;
    public static String CustomTxtParserInputWizardPage_removeGroup;
    public static String CustomTxtParserInputWizardPage_removeLine;
    public static String CustomTxtParserInputWizardPage_set;
    public static String CustomTxtParserInputWizardPage_timestampFormat;
    public static String CustomTxtParserInputWizardPage_uncapturedText;
    public static String CustomTxtParserInputWizardPage_unidentifiedCaptureGroup;
    public static String CustomTxtParserInputWizardPage_windowTitleEdit;
    public static String CustomTxtParserInputWizardPage_windowTitleNew;
    public static String CustomTxtParserOutputWizardPage_description;
    public static String CustomTxtParserOutputWizardPage_moveAfter;
    public static String CustomTxtParserOutputWizardPage_moveBefore;
    public static String CustomTxtParserOutputWizardPage_visible;
    public static String CustomXmlParserInputWizardPage_emptyLogTypeError;
    public static String CustomXmlParserInputWizardPage_duplicatelogTypeError;
    public static String CustomXmlParserInputWizardPage_noDocumentError;
    public static String CustomXmlParserInputWizardPage_missingLogEntryError;
    public static String CustomXmlParserInputWizardPage_missingTimestampFmtError;
    public static String CustomXmlParserInputWizardPage_invalidTimestampFmtError;
    public static String CustomXmlParserInputWizardPage_notimestamporAttributeError;
    public static String CustomXmlParserInputWizardPage_missingDocumentElementError;
    public static String CustomXmlParserInputWizardPage_timestampFormatPrompt;
    public static String CustomXmlParserInputWizardPage_timestampElementPrompt;
    public static String CustomXmlParserInputWizardPage_missingInputElementNameError;
    public static String CustomXmlParserInputWizardPage_attributePrompt;
    public static String CustomXmlParserInputWizardPage_missingAttribute;
    public static String CustomXmlParserInputWizardPage_duplicateAttributeError;
    public static String CustomXmlParserInputWizardPage_missingTimestampInFmtError;
    public static String CustomXmlParserInputWizardPage_invalidTimestampInFmtError;
    public static String CustomXmlParserInputWizardPage_missingDataGroupNameError;
    public static String CustomXmlParserInputWizardPage_missingElementNameError;
    public static String CustomXmlParserInputWizardPage_duplicateElementNameError;
    public static String CustomXmlParserInputWizardPage_addAttribute;
    public static String CustomXmlParserInputWizardPage_addChildElement;
    public static String CustomXmlParserInputWizardPage_addDocumentEleemnt;
    public static String CustomXmlParserInputWizardPage_addDocumentElement;
    public static String CustomXmlParserInputWizardPage_addNextElement;
    public static String CustomXmlParserInputWizardPage_append;
    public static String CustomXmlParserInputWizardPage_appendWith;
    public static String CustomXmlParserInputWizardPage_attibute;
    public static String CustomXmlParserInputWizardPage_dateFormatHelp;
    public static String CustomXmlParserInputWizardPage_descriptionEdit;
    public static String CustomXmlParserInputWizardPage_descriptionNew;
    public static String CustomXmlParserInputWizardPage_elementName;
    public static String CustomXmlParserInputWizardPage_feelingLucky;
    public static String CustomXmlParserInputWizardPage_format;
    public static String CustomXmlParserInputWizardPage_logEntry;
    public static String CustomXmlParserInputWizardPage_logType;
    public static String CustomXmlParserInputWizardPage_moveDown;
    public static String CustomXmlParserInputWizardPage_moveUp;
    public static String CustomXmlParserInputWizardPage_name;
    public static String CustomXmlParserInputWizardPage_newAttibute;
    public static String CustomXmlParserInputWizardPage_noMatchingAttribute;
    public static String CustomXmlParserInputWizardPage_noMatch;
    public static String CustomXmlParserInputWizardPage_noMatchingElement;
    public static String CustomXmlParserInputWizardPage_preview;
    public static String CustomXmlParserInputWizardPage_previewInput;
    public static String CustomXmlParserInputWizardPage_removeAttribute;
    public static String CustomXmlParserInputWizardPage_removeElement;
    public static String CustomXmlParserInputWizardPage_set;
    public static String CustomXmlParserInputWizardPage_tagName;
    public static String CustomXmlParserInputWizardPage_timestampFormat;
    public static String CustomXmlParserInputWizardPage_titleEdit;
    public static String CustomXmlParserInputWizardPage_titleNew;
    public static String CustomXmlParserOutputWizardPage_description;
    public static String CustomXmlParserOutputWizardPage_moveAfter;
    public static String CustomXmlParserOutputWizardPage_moveBefore;
    public static String CustomXmlParserOutputWizardPage_visible;

    public static String FilterDialog_FilterDialogTitle;
    public static String FilterView_AddActionToolTipText;
    public static String FilterView_DeleteActionToolTipText;
    public static String FilterView_ExportActionToolTipText;
    public static String FilterView_FileDialogFilterName;
    public static String FilterView_ImportActionToolTipText;
    public static String FilterView_SaveActionToolTipText;
    public static String FilterViewer_AlphaButtonText;
    public static String FilterViewer_DeleteActionText;
    public static String FilterViewer_FieldLabel;
    public static String FilterViewer_FilterNameHint;
    public static String FilterViewer_IgnoreCaseButtonText;
    public static String FilterViewer_NameLabel;
    public static String FilterViewer_NewPrefix;
    public static String FilterViewer_NotLabel;
    public static String FilterViewer_NumButtonText;
    public static String FilterViewer_RegexHint;
    public static String FilterViewer_RegexLabel;
    public static String FilterViewer_ResultLabel;
    public static String FilterViewer_TimestampButtonText;
    public static String FilterViewer_TypeLabel;
    public static String FilterViewer_ValueHint;
    public static String FilterViewer_ValueLabel;

    static {
        // initialize resource bundle
        NLS.initializeMessages(BUNDLE_NAME, Messages.class);
    }

    private Messages() {
    }
}

==> org.eclipse.linuxtools.tmf.ui.source_0.5.0.201205301612.jar: org/eclipse/linuxtools/internal/tmf/ui/Messages.java <==
package org.eclipse.linuxtools.internal.tmf.ui;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
    private static final String BUNDLE_NAME = "org.eclipse.linuxtools.internal.tmf.ui.messages"; //$NON-NLS-1$

    public static String ManageCustomParsersDialog_DeleteButtonLabel;
    public static String ManageCustomParsersDialog_DeleteConfirmation;
    public static String ManageCustomParsersDialog_DeleteParserDialogHeader;
    public static String ManageCustomParsersDialog_DialogHeader;
    public static String ManageCustomParsersDialog_EditButtonLabel;
    public static String ManageCustomParsersDialog_ExportButtonLabel;
    public static String ManageCustomParsersDialog_ExportParserSelection;
    public static String ManageCustomParsersDialog_ImportButtonLabel;
    public static String ManageCustomParsersDialog_ImportParserSelection;
    public static String ManageCustomParsersDialog_NewButtonLabel;
    public static String ManageCustomParsersDialog_ParseButtonLabel;
    public static String ManageCustomParsersDialog_ParseError;
    public static String ManageCustomParsersDialog_TextButtonLabel;
    public static String ManageCustomParsersDialog_TraceSelection;

    public static String CustomTraceDefinition_messageTag;
    public static String CustomTraceDefinition_otherTag;
    public static String CustomTraceDefinition_timestampTag;
    public static String CustomTxtTraceDefinition_action;
    public static String CustomTxtTraceDefinition_cardinality;
    public static String CustomTxtTraceDefinition_definition;
    public static String CustomTxtTraceDefinition_definitionRootElement;
    public static String CustomTxtTraceDefinition_format;
    public static String CustomTxtTraceDefinition_inputData;
    public static String CustomTxtTraceDefinition_inputLine;
    public static String CustomTxtTraceDefinition_max;
    public static String CustomTxtTraceDefinition_min;
    public static String CustomTxtTraceDefinition_name;
    public static String CustomTxtTraceDefinition_outputColumn;
    public static String CustomTxtTraceDefinition_regEx;
    public static String CustomTxtTraceDefinition_timestampOutputFormat;
    public static String CustomXmlTraceDefinition_action;
    public static String CustomXmlTraceDefinition_attribute;
    public static String CustomXmlTraceDefinition_definition;
    public static String CustomXmlTraceDefinition_definitionRootElement;
    public static String CustomXmlTraceDefinition_format;
    public static String CustomXmlTraceDefinition_ignoreTag;
    public static String CustomXmlTraceDefinition_inputData;
    public static String CustomXmlTraceDefinition_inputElement;
    public static String CustomXmlTraceDefinition_logEntry;
    public static String CustomXmlTraceDefinition_name;
    public static String CustomXmlTraceDefinition_outputColumn;
    public static String CustomXmlTraceDefinition_timestampOutputFormat;

    public static String TmfEventsTable_AddBookmarkActionText;
    public static String TmfEventsTable_AddBookmarkDialogText;
    public static String TmfEventsTable_AddBookmarkDialogTitle;
    public static String TmfEventsTable_ApplyPresetFilterMenuName;
    public static String TmfEventsTable_ClearFiltersActionText;
    public static String TmfEventsTable_ContentColumnHeader;
    public static String TmfEventsTable_FilterHint;
    public static String TmfEventsTable_HideRawActionText;
    public static String TmfEventsTable_HideTableActionText;
    public static String TmfEventsTable_ReferenceColumnHeader;
    public static String TmfEventsTable_RemoveBookmarkActionText;
    public static String TmfEventsTable_SearchHint;
    public static String TmfEventsTable_SearchingJobName;
    public static String TmfEventsTable_ShowFilterBarActionText;
    public static String TmfEventsTable_ShowRawActionText;
    public static String TmfEventsTable_ShowSearchBarActionText;
    public static String TmfEventsTable_ShowTableActionText;
    public static String TmfEventsTable_SourceColumnHeader;
    public static String TmfEventsTable_TimestampColumnHeader;
    public static String TmfEventsTable_TypeColumnHeader;

    public static String TmfTimeFilterDialog_EDIT_PROFILING_OPTIONS;
    public static String TmfTimeFilterDialog_TRACE_FILTER;
    public static String TmfTimeFilterDialog_TRACE_FILTER_DESC;
    public static String TmfTimeFilterDialog_TRACE_ID;
    public static String TmfTimeFilterDialog_TRACE_NAME;
    public static String TmfTimeLegend_LEGEND;
    public static String TmfTimeLegend_TRACE_STATES;
    public static String TmfTimeLegend_TRACE_STATES_TITLE;
    public static String TmfTimeLegend_WINDOW_TITLE;
    public static String TmfTimeLegend_StateTypeName;

    public static String TmfTimeStatesCtrl_TRACE_GROUP_LABEL;
    public static String TmfTimeStatesCtrl_UNDEFINED_GROUP;
    public static String TmfTimeTipHandler_DURATION;
    public static String TmfTimeTipHandler_NUMBER_OF_TRACES;
    public static String TmfTimeTipHandler_TRACE_DATE;
    public static String TmfTimeTipHandler_TRACE_EVENT_TIME;
    public static String TmfTimeTipHandler_TRACE_GROUP_NAME;
    public static String TmfTimeTipHandler_TRACE_NAME;
    public static String TmfTimeTipHandler_TRACE_START_TIME;
    public static String TmfTimeTipHandler_TRACE_STATE;
    public static String TmfTimeTipHandler_TRACE_STOP_TIME;

    public static String TmfTimeGraphViewer_ResetScaleActionNameText;
    public static String TmfTimeGraphViewer_ResetScaleActionToolTipText;
    public static String TmfTimeGraphViewer_LegendActionNameText;
    public static String TmfTimeGraphViewer_LegendActionToolTipText;
    public static String TmfTimeGraphViewer_NextEventActionNameText;
    public static String TmfTimeGraphViewer_NextEventActionToolTipText;
    public static String TmfTimeGraphViewer_PreviousEventActionNameText;
    public static String TmfTimeGraphViewer_PreviousEventActionToolTipText;
    public static String TmfTimeGraphViewer_NextItemActionNameText;
    public static String TmfTimeGraphViewer_NextItemActionToolTipText;
    public static String TmfTimeGraphViewer_PreviousItemActionNameText;
    public static String TmfTimeGraphViewer_PreviousItemActionToolTipText;
    public static String TmfTimeGraphViewer_ZoomInActionNameText;
    public static String TmfTimeGraphViewer_ZoomInActionToolTipText;
    public static String TmfTimeGraphViewer_ZoomOutActionNameText;
    public static String TmfTimeGraphViewer_ZoomOutActionToolTipText;
    
    public static String ColorsView_AddActionToolTipText;
    public static String ColorsView_BackgroundButtonText;
    public static String ColorsView_BackgroundDialogText;
    public static String ColorsView_DeleteActionToolTipText;
    public static String ColorsView_ExportActionToolTipText;
    public static String ColorsView_FilterButtonText;
    public static String ColorsView_ForegroundButtonText;
    public static String ColorsView_ForegroundDialogText;
    public static String ColorsView_ImportActionToolTipText;
    public static String ColorsView_ImportOverwriteDialogMessage1;
    public static String ColorsView_ImportOverwriteDialogMessage2;
    public static String ColorsView_ImportOverwriteDialogTitle;
    public static String ColorsView_MoveDownActionToolTipText;
    public static String ColorsView_MoveUpActionToolTipText;
    public static String ColorsView_TickButtonText;
    public static String TickColorDialog_TickColorDialogTitle;

    public static String CustomTxtParserInputWizardPage_addChildLine;
    public static String CustomTxtParserInputWizardPage_addGroup;
    public static String CustomTxtParserInputWizardPage_addNextLine;
    public static String CustomTxtParserInputWizardPage_append;
    public static String CustomTxtParserInputWizardPage_appendWith;
    public static String CustomTxtParserInputWizardPage_capturedGroup;
    public static String CustomTxtParserInputWizardPage_cardinality;
    public static String CustomTxtParserInputWizardPage_dateFormatHelp;
    public static String CustomTxtParserInputWizardPage_desccriptionEdit;
    public static String CustomTxtParserInputWizardPage_descriptionNew;
    public static String CustomTxtParserInputWizardPage_format;
    public static String CustomTxtParserInputWizardPage_group;
    public static String CustomTxtParserInputWizardPage_highlightAll;
    public static String CustomTxtParserInputWizardPage_logType;
    public static String CustomTxtParserInputWizardPage_matchingLineRoot;
    public static String CustomTxtParserInputWizardPage_matchingOtherLine;
    public static String CustomTxtParserInputWizardPage_matchingRootLine;
    public static String CustomTxtParserInputWizardPage_max;
    public static String CustomTxtParserInputWizardPage_min;
    public static String CustomTxtParserInputWizardPage_moveDown;
    public static String CustomTxtParserInputWizardPage_moveUp;
    public static String CustomTxtParserInputWizardPage_name;
    public static String CustomTxtParserInputWizardPage_newGroup;
    public static String CustomTxtParserInputWizardPage_noMatch;
    public static String CustomTxtParserInputWizardPage_noMatchingGroup;
    public static String CustomTxtParserInputWizardPage_noMatchingLine;
    public static String CustomTxtParserInputWizardPage_noMatchingTimestamp;
    public static String CustomTxtParserInputWizardPage_noMathcingLine;
    public static String CustomTxtParserInputWizardPage_nonMatchingLine;
    public static String CustomTxtParserInputWizardPage_noTimestampGroup;
    public static String CustomTxtParserInputWizardPage_preview;
    public static String CustomTxtParserInputWizardPage_previewInput;
    public static String CustomTxtParserInputWizardPage_previewLegend;
    public static String CustomTxtParserInputWizardPage_regularExpression;
    public static String CustomTxtParserInputWizardPage_regularExpressionHelp;
    public static String CustomTxtParserInputWizardPage_removeGroup;
    public static String CustomTxtParserInputWizardPage_removeLine;
    public static String CustomTxtParserInputWizardPage_set;
    public static String CustomTxtParserInputWizardPage_timestampFormat;
    public static String CustomTxtParserInputWizardPage_uncapturedText;
    public static String CustomTxtParserInputWizardPage_unidentifiedCaptureGroup;
    public static String CustomTxtParserInputWizardPage_windowTitleEdit;
    public static String CustomTxtParserInputWizardPage_windowTitleNew;
    public static String CustomTxtParserOutputWizardPage_description;
    public static String CustomTxtParserOutputWizardPage_moveAfter;
    public static String CustomTxtParserOutputWizardPage_moveBefore;
    public static String CustomTxtParserOutputWizardPage_visible;
    public static String CustomXmlParserInputWizardPage_emptyLogTypeError;
    public static String CustomXmlParserInputWizardPage_duplicatelogTypeError;
    public static String CustomXmlParserInputWizardPage_noDocumentError;
    public static String CustomXmlParserInputWizardPage_missingLogEntryError;
    public static String CustomXmlParserInputWizardPage_missingTimestampFmtError;
    public static String CustomXmlParserInputWizardPage_invalidTimestampFmtError;
    public static String CustomXmlParserInputWizardPage_notimestamporAttributeError;
    public static String CustomXmlParserInputWizardPage_missingDocumentElementError;
    public static String CustomXmlParserInputWizardPage_timestampFormatPrompt;
    public static String CustomXmlParserInputWizardPage_timestampElementPrompt;
    public static String CustomXmlParserInputWizardPage_missingInputElementNameError;
    public static String CustomXmlParserInputWizardPage_attributePrompt;
    public static String CustomXmlParserInputWizardPage_missingAttribute;
    public static String CustomXmlParserInputWizardPage_duplicateAttributeError;
    public static String CustomXmlParserInputWizardPage_missingTimestampInFmtError;
    public static String CustomXmlParserInputWizardPage_invalidTimestampInFmtError;
    public static String CustomXmlParserInputWizardPage_missingDataGroupNameError;
    public static String CustomXmlParserInputWizardPage_missingElementNameError;
    public static String CustomXmlParserInputWizardPage_duplicateElementNameError;
    public static String CustomXmlParserInputWizardPage_addAttribute;
    public static String CustomXmlParserInputWizardPage_addChildElement;
    public static String CustomXmlParserInputWizardPage_addDocumentEleemnt;
    public static String CustomXmlParserInputWizardPage_addDocumentElement;
    public static String CustomXmlParserInputWizardPage_addNextElement;
    public static String CustomXmlParserInputWizardPage_append;
    public static String CustomXmlParserInputWizardPage_appendWith;
    public static String CustomXmlParserInputWizardPage_attibute;
    public static String CustomXmlParserInputWizardPage_dateFormatHelp;
    public static String CustomXmlParserInputWizardPage_descriptionEdit;
    public static String CustomXmlParserInputWizardPage_descriptionNew;
    public static String CustomXmlParserInputWizardPage_elementName;
    public static String CustomXmlParserInputWizardPage_feelingLucky;
    public static String CustomXmlParserInputWizardPage_format;
    public static String CustomXmlParserInputWizardPage_logEntry;
    public static String CustomXmlParserInputWizardPage_logType;
    public static String CustomXmlParserInputWizardPage_moveDown;
    public static String CustomXmlParserInputWizardPage_moveUp;
    public static String CustomXmlParserInputWizardPage_name;
    public static String CustomXmlParserInputWizardPage_newAttibute;
    public static String CustomXmlParserInputWizardPage_noMatchingAttribute;
    public static String CustomXmlParserInputWizardPage_noMatch;
    public static String CustomXmlParserInputWizardPage_noMatchingElement;
    public static String CustomXmlParserInputWizardPage_preview;
    public static String CustomXmlParserInputWizardPage_previewInput;
    public static String CustomXmlParserInputWizardPage_removeAttribute;
    public static String CustomXmlParserInputWizardPage_removeElement;
    public static String CustomXmlParserInputWizardPage_set;
    public static String CustomXmlParserInputWizardPage_tagName;
    public static String CustomXmlParserInputWizardPage_timestampFormat;
    public static String CustomXmlParserInputWizardPage_titleEdit;
    public static String CustomXmlParserInputWizardPage_titleNew;
    public static String CustomXmlParserOutputWizardPage_description;
    public static String CustomXmlParserOutputWizardPage_moveAfter;
    public static String CustomXmlParserOutputWizardPage_moveBefore;
    public static String CustomXmlParserOutputWizardPage_visible;

    public static String FilterDialog_FilterDialogTitle;
    public static String FilterView_AddActionToolTipText;
    public static String FilterView_DeleteActionToolTipText;
    public static String FilterView_ExportActionToolTipText;
    public static String FilterView_FileDialogFilterName;
    public static String FilterView_ImportActionToolTipText;
    public static String FilterView_SaveActionToolTipText;
    public static String FilterViewer_EmptyTreeHintText;
    public static String FilterViewer_CommonCategory;
    public static String FilterViewer_AlphaButtonText;
    public static String FilterViewer_DeleteActionText;
    public static String FilterViewer_FieldLabel;
    public static String FilterViewer_FilterNameHint;
    public static String FilterViewer_IgnoreCaseButtonText;
    public static String FilterViewer_NameLabel;
    public static String FilterViewer_NewPrefix;
    public static String FilterViewer_NotLabel;
    public static String FilterViewer_NumButtonText;
    public static String FilterViewer_RegexHint;
    public static String FilterViewer_RegexLabel;
    public static String FilterViewer_ResultLabel;
    public static String FilterViewer_TimestampButtonText;
    public static String FilterViewer_TypeLabel;
    public static String FilterViewer_ValueHint;
    public static String FilterViewer_ValueLabel;

    static {
        // initialize resource bundle
        NLS.initializeMessages(BUNDLE_NAME, Messages.class);
    }

    private Messages() {
    }
}
